/* AisleRiot - menu.h
 * Copyright (C) 1998, 2003 Jonathan Blandford <jrb@mit.edu>
 *
 * This game is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 */

#ifndef MENU_H
#define MENU_H

void random_seed ( void );
void undo_callback ( void );
void redo_callback ( void );
void create_menus ( void );
void toolbar_hide ( void );
void undo_set_sensitive (gboolean state);
void redo_set_sensitive (gboolean state);
void option_list_set_sensitive (void);
void help_update_game_name (gchar * name);
void install_options_menu (gchar *name);

extern GtkUIManager *ui_manager;
extern GtkWidget *menubar;
extern GtkWidget *toolbar;

#endif
